﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private bool editingEnabled = false;
        
        public MainWindow()
        {
            InitializeComponent();

            List<MyRecord> list = new List<MyRecord>();
            list.Add(new MyRecord() { ID = 5, Name = "Alice" });
            list.Add(new MyRecord() { ID = 7, Name = "Bob" });

            this.DataGrid.DataSource = list;
        }

        private void dataGrid_EditModeStarting(object sender, Infragistics.Windows.DataPresenter.Events.EditModeStartingEventArgs e)
        {
            // this will disable editing for the AddRecord cells when the "editingEnabled" flag is not enabled
            if (e.Cell.Record.IsAddRecord)
            {
                if (!editingEnabled)
                {
                    e.Cancel = true;
                }
            }
        }

        // add button handler
        private void ButtonAdd_Click(object sender, RoutedEventArgs e)
        {
            if (editingEnabled)
            {
                // add the record when in editing mode
                this.DataGrid.RecordManager.CommitAddRecord();
                editingEnabled = false;
            }
            else
            {
                // enter editing mode
                editingEnabled = true;
                this.DataGrid.ActiveCell = this.DataGrid.RecordManager.CurrentAddRecord.Cells[0];
                this.DataGrid.ExecuteCommand(DataPresenterCommands.StartEditMode);
            }
        }
        
        // delete button handler
        private void ButtonDelete_Click(object sender, RoutedEventArgs e)
        {
            editingEnabled = false;
            DataGrid.ActiveRecord.IsSelected = true;
            DataGrid.ExecuteCommand(DataPresenterCommands.DeleteSelectedDataRecords);
        }

        private void dataGrid_KeyUp(object sender, KeyEventArgs e)
        {
            // clear the "editingEnabled" flag when the Enter key is pressed
            if (editingEnabled && e.Key == Key.Enter)
            {
                editingEnabled = false;
            }
        }
    }

    public class MyRecord
    {
        public int ID { get; set; }
        public string Name { get; set; }
    }

}
